@@ -13,11 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
+from google.protobuf import duration_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.datalabeling_v1beta1.types import annotation_spec_set
-from google.protobuf import duration_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.datalabeling.v1beta1",
@@ -108,14 +109,29 @@ class Annotation(proto.Message):
             Output only. Sentiment for this annotation.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    annotation_source = proto.Field(proto.ENUM, number=2, enum="AnnotationSource",)
-    annotation_value = proto.Field(proto.MESSAGE, number=3, message="AnnotationValue",)
-    annotation_metadata = proto.Field(
-        proto.MESSAGE, number=4, message="AnnotationMetadata",
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    annotation_sentiment = proto.Field(
-        proto.ENUM, number=6, enum="AnnotationSentiment",
+    annotation_source: "AnnotationSource" = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="AnnotationSource",
+    )
+    annotation_value: "AnnotationValue" = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="AnnotationValue",
+    )
+    annotation_metadata: "AnnotationMetadata" = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="AnnotationMetadata",
+    )
+    annotation_sentiment: "AnnotationSentiment" = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum="AnnotationSentiment",
     )
 
 
@@ -178,53 +194,59 @@ class AnnotationValue(proto.Message):
             This field is a member of `oneof`_ ``value_type``.
     """
 
-    image_classification_annotation = proto.Field(
+    image_classification_annotation: "ImageClassificationAnnotation" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="value_type",
         message="ImageClassificationAnnotation",
     )
-    image_bounding_poly_annotation = proto.Field(
+    image_bounding_poly_annotation: "ImageBoundingPolyAnnotation" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="value_type",
         message="ImageBoundingPolyAnnotation",
     )
-    image_polyline_annotation = proto.Field(
-        proto.MESSAGE, number=8, oneof="value_type", message="ImagePolylineAnnotation",
+    image_polyline_annotation: "ImagePolylineAnnotation" = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        oneof="value_type",
+        message="ImagePolylineAnnotation",
     )
-    image_segmentation_annotation = proto.Field(
+    image_segmentation_annotation: "ImageSegmentationAnnotation" = proto.Field(
         proto.MESSAGE,
         number=9,
         oneof="value_type",
         message="ImageSegmentationAnnotation",
     )
-    text_classification_annotation = proto.Field(
+    text_classification_annotation: "TextClassificationAnnotation" = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="value_type",
         message="TextClassificationAnnotation",
     )
-    text_entity_extraction_annotation = proto.Field(
+    text_entity_extraction_annotation: "TextEntityExtractionAnnotation" = proto.Field(
         proto.MESSAGE,
         number=10,
         oneof="value_type",
         message="TextEntityExtractionAnnotation",
     )
-    video_classification_annotation = proto.Field(
+    video_classification_annotation: "VideoClassificationAnnotation" = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="value_type",
         message="VideoClassificationAnnotation",
     )
-    video_object_tracking_annotation = proto.Field(
+    video_object_tracking_annotation: "VideoObjectTrackingAnnotation" = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="value_type",
         message="VideoObjectTrackingAnnotation",
     )
-    video_event_annotation = proto.Field(
-        proto.MESSAGE, number=6, oneof="value_type", message="VideoEventAnnotation",
+    video_event_annotation: "VideoEventAnnotation" = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        oneof="value_type",
+        message="VideoEventAnnotation",
     )
 
 
@@ -236,8 +258,10 @@ class ImageClassificationAnnotation(proto.Message):
             Label of image.
     """
 
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=annotation_spec_set.AnnotationSpec,
     )
 
 
@@ -253,8 +277,14 @@ class Vertex(proto.Message):
             Y coordinate.
     """
 
-    x = proto.Field(proto.INT32, number=1,)
-    y = proto.Field(proto.INT32, number=2,)
+    x: int = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    y: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
 
 
 class NormalizedVertex(proto.Message):
@@ -269,31 +299,43 @@ class NormalizedVertex(proto.Message):
             Y coordinate.
     """
 
-    x = proto.Field(proto.FLOAT, number=1,)
-    y = proto.Field(proto.FLOAT, number=2,)
+    x: float = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    y: float = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
 
 
 class BoundingPoly(proto.Message):
     r"""A bounding polygon in the image.
 
     Attributes:
-        vertices (Sequence[google.cloud.datalabeling_v1beta1.types.Vertex]):
+        vertices (MutableSequence[google.cloud.datalabeling_v1beta1.types.Vertex]):
             The bounding polygon vertices.
     """
 
-    vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="Vertex",)
+    vertices: MutableSequence["Vertex"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Vertex",
+    )
 
 
 class NormalizedBoundingPoly(proto.Message):
     r"""Normalized bounding polygon.
 
     Attributes:
-        normalized_vertices (Sequence[google.cloud.datalabeling_v1beta1.types.NormalizedVertex]):
+        normalized_vertices (MutableSequence[google.cloud.datalabeling_v1beta1.types.NormalizedVertex]):
             The bounding polygon normalized vertices.
     """
 
-    normalized_vertices = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="NormalizedVertex",
+    normalized_vertices: MutableSequence["NormalizedVertex"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="NormalizedVertex",
     )
 
 
@@ -319,14 +361,22 @@ class ImageBoundingPolyAnnotation(proto.Message):
             Label of object in this bounding polygon.
     """
 
-    bounding_poly = proto.Field(
-        proto.MESSAGE, number=2, oneof="bounded_area", message="BoundingPoly",
+    bounding_poly: "BoundingPoly" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="bounded_area",
+        message="BoundingPoly",
     )
-    normalized_bounding_poly = proto.Field(
-        proto.MESSAGE, number=3, oneof="bounded_area", message="NormalizedBoundingPoly",
+    normalized_bounding_poly: "NormalizedBoundingPoly" = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        oneof="bounded_area",
+        message="NormalizedBoundingPoly",
     )
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=annotation_spec_set.AnnotationSpec,
     )
 
 
@@ -334,23 +384,29 @@ class Polyline(proto.Message):
     r"""A line with multiple line segments.
 
     Attributes:
-        vertices (Sequence[google.cloud.datalabeling_v1beta1.types.Vertex]):
+        vertices (MutableSequence[google.cloud.datalabeling_v1beta1.types.Vertex]):
             The polyline vertices.
     """
 
-    vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="Vertex",)
+    vertices: MutableSequence["Vertex"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Vertex",
+    )
 
 
 class NormalizedPolyline(proto.Message):
     r"""Normalized polyline.
 
     Attributes:
-        normalized_vertices (Sequence[google.cloud.datalabeling_v1beta1.types.NormalizedVertex]):
+        normalized_vertices (MutableSequence[google.cloud.datalabeling_v1beta1.types.NormalizedVertex]):
             The normalized polyline vertices.
     """
 
-    normalized_vertices = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="NormalizedVertex",
+    normalized_vertices: MutableSequence["NormalizedVertex"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="NormalizedVertex",
     )
 
 
@@ -375,12 +431,22 @@ class ImagePolylineAnnotation(proto.Message):
             Label of this polyline.
     """
 
-    polyline = proto.Field(proto.MESSAGE, number=2, oneof="poly", message="Polyline",)
-    normalized_polyline = proto.Field(
-        proto.MESSAGE, number=3, oneof="poly", message="NormalizedPolyline",
+    polyline: "Polyline" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="poly",
+        message="Polyline",
     )
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+    normalized_polyline: "NormalizedPolyline" = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        oneof="poly",
+        message="NormalizedPolyline",
+    )
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=annotation_spec_set.AnnotationSpec,
     )
 
 
@@ -388,7 +454,7 @@ class ImageSegmentationAnnotation(proto.Message):
     r"""Image segmentation annotation.
 
     Attributes:
-        annotation_colors (Sequence[google.cloud.datalabeling_v1beta1.types.ImageSegmentationAnnotation.AnnotationColorsEntry]):
+        annotation_colors (MutableMapping[str, google.cloud.datalabeling_v1beta1.types.AnnotationSpec]):
             The mapping between rgb color and annotation
             spec. The key is the rgb color represented in
             format of rgb(0, 0, 0). The value is the
@@ -399,14 +465,22 @@ class ImageSegmentationAnnotation(proto.Message):
             A byte string of a full image's color map.
     """
 
-    annotation_colors = proto.MapField(
+    annotation_colors: MutableMapping[
+        str, annotation_spec_set.AnnotationSpec
+    ] = proto.MapField(
         proto.STRING,
         proto.MESSAGE,
         number=1,
         message=annotation_spec_set.AnnotationSpec,
     )
-    mime_type = proto.Field(proto.STRING, number=2,)
-    image_bytes = proto.Field(proto.BYTES, number=3,)
+    mime_type: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    image_bytes: bytes = proto.Field(
+        proto.BYTES,
+        number=3,
+    )
 
 
 class TextClassificationAnnotation(proto.Message):
@@ -417,8 +491,10 @@ class TextClassificationAnnotation(proto.Message):
             Label of the text.
     """
 
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=annotation_spec_set.AnnotationSpec,
     )
 
 
@@ -432,11 +508,15 @@ class TextEntityExtractionAnnotation(proto.Message):
             Position of the entity.
     """
 
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=annotation_spec_set.AnnotationSpec,
     )
-    sequential_segment = proto.Field(
-        proto.MESSAGE, number=2, message="SequentialSegment",
+    sequential_segment: "SequentialSegment" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="SequentialSegment",
     )
 
 
@@ -450,8 +530,14 @@ class SequentialSegment(proto.Message):
             End position (exclusive).
     """
 
-    start = proto.Field(proto.INT32, number=1,)
-    end = proto.Field(proto.INT32, number=2,)
+    start: int = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    end: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
 
 
 class TimeSegment(proto.Message):
@@ -469,11 +555,15 @@ class TimeSegment(proto.Message):
             start.
     """
 
-    start_time_offset = proto.Field(
-        proto.MESSAGE, number=1, message=duration_pb2.Duration,
+    start_time_offset: duration_pb2.Duration = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=duration_pb2.Duration,
     )
-    end_time_offset = proto.Field(
-        proto.MESSAGE, number=2, message=duration_pb2.Duration,
+    end_time_offset: duration_pb2.Duration = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=duration_pb2.Duration,
     )
 
 
@@ -488,9 +578,15 @@ class VideoClassificationAnnotation(proto.Message):
             Label of the segment specified by time_segment.
     """
 
-    time_segment = proto.Field(proto.MESSAGE, number=1, message="TimeSegment",)
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=2, message=annotation_spec_set.AnnotationSpec,
+    time_segment: "TimeSegment" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="TimeSegment",
+    )
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=annotation_spec_set.AnnotationSpec,
     )
 
 
@@ -517,13 +613,23 @@ class ObjectTrackingFrame(proto.Message):
             beginning of the video.
     """
 
-    bounding_poly = proto.Field(
-        proto.MESSAGE, number=1, oneof="bounded_area", message="BoundingPoly",
+    bounding_poly: "BoundingPoly" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        oneof="bounded_area",
+        message="BoundingPoly",
     )
-    normalized_bounding_poly = proto.Field(
-        proto.MESSAGE, number=2, oneof="bounded_area", message="NormalizedBoundingPoly",
+    normalized_bounding_poly: "NormalizedBoundingPoly" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="bounded_area",
+        message="NormalizedBoundingPoly",
+    )
+    time_offset: duration_pb2.Duration = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=duration_pb2.Duration,
     )
-    time_offset = proto.Field(proto.MESSAGE, number=3, message=duration_pb2.Duration,)
 
 
 class VideoObjectTrackingAnnotation(proto.Message):
@@ -536,17 +642,27 @@ class VideoObjectTrackingAnnotation(proto.Message):
         time_segment (google.cloud.datalabeling_v1beta1.types.TimeSegment):
             The time segment of the video to which object
             tracking applies.
-        object_tracking_frames (Sequence[google.cloud.datalabeling_v1beta1.types.ObjectTrackingFrame]):
+        object_tracking_frames (MutableSequence[google.cloud.datalabeling_v1beta1.types.ObjectTrackingFrame]):
             The list of frames where this object track
             appears.
     """
 
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=annotation_spec_set.AnnotationSpec,
     )
-    time_segment = proto.Field(proto.MESSAGE, number=2, message="TimeSegment",)
-    object_tracking_frames = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="ObjectTrackingFrame",
+    time_segment: "TimeSegment" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="TimeSegment",
+    )
+    object_tracking_frames: MutableSequence[
+        "ObjectTrackingFrame"
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="ObjectTrackingFrame",
     )
 
 
@@ -561,10 +677,16 @@ class VideoEventAnnotation(proto.Message):
             annotation applies.
     """
 
-    annotation_spec = proto.Field(
-        proto.MESSAGE, number=1, message=annotation_spec_set.AnnotationSpec,
+    annotation_spec: annotation_spec_set.AnnotationSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=annotation_spec_set.AnnotationSpec,
+    )
+    time_segment: "TimeSegment" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="TimeSegment",
     )
-    time_segment = proto.Field(proto.MESSAGE, number=2, message="TimeSegment",)
 
 
 class AnnotationMetadata(proto.Message):
@@ -575,8 +697,10 @@ class AnnotationMetadata(proto.Message):
             Metadata related to human labeling.
     """
 
-    operator_metadata = proto.Field(
-        proto.MESSAGE, number=2, message="OperatorMetadata",
+    operator_metadata: "OperatorMetadata" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="OperatorMetadata",
     )
 
 
@@ -596,14 +720,26 @@ class OperatorMetadata(proto.Message):
         label_votes (int):
             The total number of contributors that choose
             this label.
-        comments (Sequence[str]):
+        comments (MutableSequence[str]):
             Comments from contributors.
     """
 
-    score = proto.Field(proto.FLOAT, number=1,)
-    total_votes = proto.Field(proto.INT32, number=2,)
-    label_votes = proto.Field(proto.INT32, number=3,)
-    comments = proto.RepeatedField(proto.STRING, number=4,)
+    score: float = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    total_votes: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    label_votes: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    comments: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
