@@ -13,18 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
+from google.protobuf import field_mask_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.datalabeling_v1beta1.types import (
     annotation_spec_set as gcd_annotation_spec_set,
 )
+from google.cloud.datalabeling_v1beta1.types import evaluation_job as gcd_evaluation_job
+from google.cloud.datalabeling_v1beta1.types import instruction as gcd_instruction
 from google.cloud.datalabeling_v1beta1.types import dataset as gcd_dataset
 from google.cloud.datalabeling_v1beta1.types import evaluation
-from google.cloud.datalabeling_v1beta1.types import evaluation_job as gcd_evaluation_job
 from google.cloud.datalabeling_v1beta1.types import human_annotation_config
-from google.cloud.datalabeling_v1beta1.types import instruction as gcd_instruction
-from google.protobuf import field_mask_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.datalabeling.v1beta1",
@@ -87,8 +88,15 @@ class CreateDatasetRequest(proto.Message):
             Required. The dataset to be created.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    dataset = proto.Field(proto.MESSAGE, number=2, message=gcd_dataset.Dataset,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    dataset: gcd_dataset.Dataset = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcd_dataset.Dataset,
+    )
 
 
 class GetDatasetRequest(proto.Message):
@@ -100,7 +108,10 @@ class GetDatasetRequest(proto.Message):
             projects/{project_id}/datasets/{dataset_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListDatasetsRequest(proto.Message):
@@ -125,17 +136,29 @@ class ListDatasetsRequest(proto.Message):
             Returns the first page if empty.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListDatasetsResponse(proto.Message):
     r"""Results of listing datasets within a project.
 
     Attributes:
-        datasets (Sequence[google.cloud.datalabeling_v1beta1.types.Dataset]):
+        datasets (MutableSequence[google.cloud.datalabeling_v1beta1.types.Dataset]):
             The list of datasets to return.
         next_page_token (str):
             A token to retrieve next page of results.
@@ -145,10 +168,15 @@ class ListDatasetsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    datasets = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gcd_dataset.Dataset,
+    datasets: MutableSequence[gcd_dataset.Dataset] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_dataset.Dataset,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteDatasetRequest(proto.Message):
@@ -160,7 +188,10 @@ class DeleteDatasetRequest(proto.Message):
             projects/{project_id}/datasets/{dataset_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ImportDataRequest(proto.Message):
@@ -179,11 +210,19 @@ class ImportDataRequest(proto.Message):
             notification will be sent.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    input_config = proto.Field(
-        proto.MESSAGE, number=2, message=gcd_dataset.InputConfig,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    input_config: gcd_dataset.InputConfig = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcd_dataset.InputConfig,
+    )
+    user_email_address: str = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    user_email_address = proto.Field(proto.STRING, number=3,)
 
 
 class ExportDataRequest(proto.Message):
@@ -210,13 +249,27 @@ class ExportDataRequest(proto.Message):
             notification will be sent.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    annotated_dataset = proto.Field(proto.STRING, number=2,)
-    filter = proto.Field(proto.STRING, number=3,)
-    output_config = proto.Field(
-        proto.MESSAGE, number=4, message=gcd_dataset.OutputConfig,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    annotated_dataset: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    output_config: gcd_dataset.OutputConfig = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=gcd_dataset.OutputConfig,
+    )
+    user_email_address: str = proto.Field(
+        proto.STRING,
+        number=5,
     )
-    user_email_address = proto.Field(proto.STRING, number=5,)
 
 
 class GetDataItemRequest(proto.Message):
@@ -228,7 +281,10 @@ class GetDataItemRequest(proto.Message):
             projects/{project_id}/datasets/{dataset_id}/dataItems/{data_item_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListDataItemsRequest(proto.Message):
@@ -253,17 +309,29 @@ class ListDataItemsRequest(proto.Message):
             Return first page if empty.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListDataItemsResponse(proto.Message):
     r"""Results of listing data items in a dataset.
 
     Attributes:
-        data_items (Sequence[google.cloud.datalabeling_v1beta1.types.DataItem]):
+        data_items (MutableSequence[google.cloud.datalabeling_v1beta1.types.DataItem]):
             The list of data items to return.
         next_page_token (str):
             A token to retrieve next page of results.
@@ -273,10 +341,15 @@ class ListDataItemsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    data_items = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gcd_dataset.DataItem,
+    data_items: MutableSequence[gcd_dataset.DataItem] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_dataset.DataItem,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetAnnotatedDatasetRequest(proto.Message):
@@ -289,7 +362,10 @@ class GetAnnotatedDatasetRequest(proto.Message):
             {annotated_dataset_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListAnnotatedDatasetsRequest(proto.Message):
@@ -314,17 +390,29 @@ class ListAnnotatedDatasetsRequest(proto.Message):
             call. Return first page if empty.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListAnnotatedDatasetsResponse(proto.Message):
     r"""Results of listing annotated datasets for a dataset.
 
     Attributes:
-        annotated_datasets (Sequence[google.cloud.datalabeling_v1beta1.types.AnnotatedDataset]):
+        annotated_datasets (MutableSequence[google.cloud.datalabeling_v1beta1.types.AnnotatedDataset]):
             The list of annotated datasets to return.
         next_page_token (str):
             A token to retrieve next page of results.
@@ -334,10 +422,17 @@ class ListAnnotatedDatasetsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    annotated_datasets = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gcd_dataset.AnnotatedDataset,
+    annotated_datasets: MutableSequence[
+        gcd_dataset.AnnotatedDataset
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_dataset.AnnotatedDataset,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteAnnotatedDatasetRequest(proto.Message):
@@ -350,7 +445,10 @@ class DeleteAnnotatedDatasetRequest(proto.Message):
             {annotated_dataset_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class LabelImageRequest(proto.Message):
@@ -407,35 +505,46 @@ class LabelImageRequest(proto.Message):
         POLYLINE = 4
         SEGMENTATION = 5
 
-    image_classification_config = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        oneof="request_config",
-        message=human_annotation_config.ImageClassificationConfig,
+    image_classification_config: human_annotation_config.ImageClassificationConfig = (
+        proto.Field(
+            proto.MESSAGE,
+            number=4,
+            oneof="request_config",
+            message=human_annotation_config.ImageClassificationConfig,
+        )
     )
-    bounding_poly_config = proto.Field(
+    bounding_poly_config: human_annotation_config.BoundingPolyConfig = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="request_config",
         message=human_annotation_config.BoundingPolyConfig,
     )
-    polyline_config = proto.Field(
+    polyline_config: human_annotation_config.PolylineConfig = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="request_config",
         message=human_annotation_config.PolylineConfig,
     )
-    segmentation_config = proto.Field(
+    segmentation_config: human_annotation_config.SegmentationConfig = proto.Field(
         proto.MESSAGE,
         number=7,
         oneof="request_config",
         message=human_annotation_config.SegmentationConfig,
     )
-    parent = proto.Field(proto.STRING, number=1,)
-    basic_config = proto.Field(
-        proto.MESSAGE, number=2, message=human_annotation_config.HumanAnnotationConfig,
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    basic_config: human_annotation_config.HumanAnnotationConfig = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=human_annotation_config.HumanAnnotationConfig,
+    )
+    feature: Feature = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=Feature,
     )
-    feature = proto.Field(proto.ENUM, number=3, enum=Feature,)
 
 
 class LabelVideoRequest(proto.Message):
@@ -490,35 +599,48 @@ class LabelVideoRequest(proto.Message):
         OBJECT_TRACKING = 3
         EVENT = 4
 
-    video_classification_config = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        oneof="request_config",
-        message=human_annotation_config.VideoClassificationConfig,
+    video_classification_config: human_annotation_config.VideoClassificationConfig = (
+        proto.Field(
+            proto.MESSAGE,
+            number=4,
+            oneof="request_config",
+            message=human_annotation_config.VideoClassificationConfig,
+        )
     )
-    object_detection_config = proto.Field(
-        proto.MESSAGE,
-        number=5,
-        oneof="request_config",
-        message=human_annotation_config.ObjectDetectionConfig,
+    object_detection_config: human_annotation_config.ObjectDetectionConfig = (
+        proto.Field(
+            proto.MESSAGE,
+            number=5,
+            oneof="request_config",
+            message=human_annotation_config.ObjectDetectionConfig,
+        )
     )
-    object_tracking_config = proto.Field(
+    object_tracking_config: human_annotation_config.ObjectTrackingConfig = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="request_config",
         message=human_annotation_config.ObjectTrackingConfig,
     )
-    event_config = proto.Field(
+    event_config: human_annotation_config.EventConfig = proto.Field(
         proto.MESSAGE,
         number=7,
         oneof="request_config",
         message=human_annotation_config.EventConfig,
     )
-    parent = proto.Field(proto.STRING, number=1,)
-    basic_config = proto.Field(
-        proto.MESSAGE, number=2, message=human_annotation_config.HumanAnnotationConfig,
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    basic_config: human_annotation_config.HumanAnnotationConfig = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=human_annotation_config.HumanAnnotationConfig,
+    )
+    feature: Feature = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=Feature,
     )
-    feature = proto.Field(proto.ENUM, number=3, enum=Feature,)
 
 
 class LabelTextRequest(proto.Message):
@@ -559,23 +681,34 @@ class LabelTextRequest(proto.Message):
         TEXT_CLASSIFICATION = 1
         TEXT_ENTITY_EXTRACTION = 2
 
-    text_classification_config = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        oneof="request_config",
-        message=human_annotation_config.TextClassificationConfig,
+    text_classification_config: human_annotation_config.TextClassificationConfig = (
+        proto.Field(
+            proto.MESSAGE,
+            number=4,
+            oneof="request_config",
+            message=human_annotation_config.TextClassificationConfig,
+        )
     )
-    text_entity_extraction_config = proto.Field(
+    text_entity_extraction_config: human_annotation_config.TextEntityExtractionConfig = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="request_config",
         message=human_annotation_config.TextEntityExtractionConfig,
     )
-    parent = proto.Field(proto.STRING, number=1,)
-    basic_config = proto.Field(
-        proto.MESSAGE, number=2, message=human_annotation_config.HumanAnnotationConfig,
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    basic_config: human_annotation_config.HumanAnnotationConfig = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=human_annotation_config.HumanAnnotationConfig,
+    )
+    feature: Feature = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum=Feature,
     )
-    feature = proto.Field(proto.ENUM, number=6, enum=Feature,)
 
 
 class GetExampleRequest(proto.Message):
@@ -592,8 +725,14 @@ class GetExampleRequest(proto.Message):
             "annotation_spec.display_name = {display_name}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ListExamplesRequest(proto.Message):
@@ -619,17 +758,29 @@ class ListExamplesRequest(proto.Message):
             Return first page if empty.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListExamplesResponse(proto.Message):
     r"""Results of listing Examples in and annotated dataset.
 
     Attributes:
-        examples (Sequence[google.cloud.datalabeling_v1beta1.types.Example]):
+        examples (MutableSequence[google.cloud.datalabeling_v1beta1.types.Example]):
             The list of examples to return.
         next_page_token (str):
             A token to retrieve next page of results.
@@ -639,10 +790,15 @@ class ListExamplesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    examples = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gcd_dataset.Example,
+    examples: MutableSequence[gcd_dataset.Example] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_dataset.Example,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CreateAnnotationSpecSetRequest(proto.Message):
@@ -658,9 +814,14 @@ class CreateAnnotationSpecSetRequest(proto.Message):
             for annotation specs with same display_name.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    annotation_spec_set = proto.Field(
-        proto.MESSAGE, number=2, message=gcd_annotation_spec_set.AnnotationSpecSet,
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    annotation_spec_set: gcd_annotation_spec_set.AnnotationSpecSet = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcd_annotation_spec_set.AnnotationSpecSet,
     )
 
 
@@ -673,7 +834,10 @@ class GetAnnotationSpecSetRequest(proto.Message):
             projects/{project_id}/annotationSpecSets/{annotation_spec_set_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListAnnotationSpecSetsRequest(proto.Message):
@@ -698,17 +862,29 @@ class ListAnnotationSpecSetsRequest(proto.Message):
             call. Return first page if empty.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListAnnotationSpecSetsResponse(proto.Message):
     r"""Results of listing annotation spec set under a project.
 
     Attributes:
-        annotation_spec_sets (Sequence[google.cloud.datalabeling_v1beta1.types.AnnotationSpecSet]):
+        annotation_spec_sets (MutableSequence[google.cloud.datalabeling_v1beta1.types.AnnotationSpecSet]):
             The list of annotation spec sets.
         next_page_token (str):
             A token to retrieve next page of results.
@@ -718,10 +894,17 @@ class ListAnnotationSpecSetsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    annotation_spec_sets = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gcd_annotation_spec_set.AnnotationSpecSet,
+    annotation_spec_sets: MutableSequence[
+        gcd_annotation_spec_set.AnnotationSpecSet
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_annotation_spec_set.AnnotationSpecSet,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteAnnotationSpecSetRequest(proto.Message):
@@ -733,7 +916,10 @@ class DeleteAnnotationSpecSetRequest(proto.Message):
             ``projects/{project_id}/annotationSpecSets/{annotation_spec_set_id}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateInstructionRequest(proto.Message):
@@ -748,9 +934,14 @@ class CreateInstructionRequest(proto.Message):
             labeling task.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    instruction = proto.Field(
-        proto.MESSAGE, number=2, message=gcd_instruction.Instruction,
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    instruction: gcd_instruction.Instruction = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcd_instruction.Instruction,
     )
 
 
@@ -763,7 +954,10 @@ class GetInstructionRequest(proto.Message):
             projects/{project_id}/instructions/{instruction_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteInstructionRequest(proto.Message):
@@ -775,7 +969,10 @@ class DeleteInstructionRequest(proto.Message):
             projects/{project_id}/instructions/{instruction_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListInstructionsRequest(proto.Message):
@@ -800,17 +997,29 @@ class ListInstructionsRequest(proto.Message):
             Return first page if empty.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListInstructionsResponse(proto.Message):
     r"""Results of listing instructions under a project.
 
     Attributes:
-        instructions (Sequence[google.cloud.datalabeling_v1beta1.types.Instruction]):
+        instructions (MutableSequence[google.cloud.datalabeling_v1beta1.types.Instruction]):
             The list of Instructions to return.
         next_page_token (str):
             A token to retrieve next page of results.
@@ -820,10 +1029,15 @@ class ListInstructionsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    instructions = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gcd_instruction.Instruction,
+    instructions: MutableSequence[gcd_instruction.Instruction] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_instruction.Instruction,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetEvaluationRequest(proto.Message):
@@ -836,7 +1050,10 @@ class GetEvaluationRequest(proto.Message):
             "projects/{project_id}/datasets/{dataset_id}/evaluations/{evaluation_id}'
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class SearchEvaluationsRequest(proto.Message):
@@ -892,17 +1109,29 @@ class SearchEvaluationsRequest(proto.Message):
             first page of the search.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class SearchEvaluationsResponse(proto.Message):
     r"""Results of searching evaluations.
 
     Attributes:
-        evaluations (Sequence[google.cloud.datalabeling_v1beta1.types.Evaluation]):
+        evaluations (MutableSequence[google.cloud.datalabeling_v1beta1.types.Evaluation]):
             The list of evaluations matching the search.
         next_page_token (str):
             A token to retrieve next page of results.
@@ -912,10 +1141,15 @@ class SearchEvaluationsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    evaluations = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=evaluation.Evaluation,
+    evaluations: MutableSequence[evaluation.Evaluation] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=evaluation.Evaluation,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class SearchExampleComparisonsRequest(proto.Message):
@@ -942,16 +1176,25 @@ class SearchExampleComparisonsRequest(proto.Message):
             first page of the search.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class SearchExampleComparisonsResponse(proto.Message):
     r"""Results of searching example comparisons.
 
     Attributes:
-        example_comparisons (Sequence[google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse.ExampleComparison]):
+        example_comparisons (MutableSequence[google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse.ExampleComparison]):
             A list of example comparisons matching the
             search criteria.
         next_page_token (str):
@@ -965,25 +1208,36 @@ class SearchExampleComparisonsResponse(proto.Message):
         Attributes:
             ground_truth_example (google.cloud.datalabeling_v1beta1.types.Example):
                 The ground truth output for the input.
-            model_created_examples (Sequence[google.cloud.datalabeling_v1beta1.types.Example]):
+            model_created_examples (MutableSequence[google.cloud.datalabeling_v1beta1.types.Example]):
                 Predictions by the model for the input.
         """
 
-        ground_truth_example = proto.Field(
-            proto.MESSAGE, number=1, message=gcd_dataset.Example,
+        ground_truth_example: gcd_dataset.Example = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message=gcd_dataset.Example,
         )
-        model_created_examples = proto.RepeatedField(
-            proto.MESSAGE, number=2, message=gcd_dataset.Example,
+        model_created_examples: MutableSequence[
+            gcd_dataset.Example
+        ] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=2,
+            message=gcd_dataset.Example,
         )
 
     @property
     def raw_page(self):
         return self
 
-    example_comparisons = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=ExampleComparison,
+    example_comparisons: MutableSequence[ExampleComparison] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=ExampleComparison,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CreateEvaluationJobRequest(proto.Message):
@@ -997,9 +1251,14 @@ class CreateEvaluationJobRequest(proto.Message):
             Required. The evaluation job to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    job = proto.Field(
-        proto.MESSAGE, number=2, message=gcd_evaluation_job.EvaluationJob,
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job: gcd_evaluation_job.EvaluationJob = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcd_evaluation_job.EvaluationJob,
     )
 
 
@@ -1022,11 +1281,15 @@ class UpdateEvaluationJobRequest(proto.Message):
             them with commas.
     """
 
-    evaluation_job = proto.Field(
-        proto.MESSAGE, number=1, message=gcd_evaluation_job.EvaluationJob,
+    evaluation_job: gcd_evaluation_job.EvaluationJob = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_evaluation_job.EvaluationJob,
     )
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -1040,7 +1303,10 @@ class GetEvaluationJobRequest(proto.Message):
             "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class PauseEvaluationJobRequest(proto.Message):
@@ -1054,7 +1320,10 @@ class PauseEvaluationJobRequest(proto.Message):
             "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ResumeEvaluationJobRequest(proto.Message):
@@ -1068,7 +1337,10 @@ class ResumeEvaluationJobRequest(proto.Message):
             "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteEvaluationJobRequest(proto.Message):
@@ -1082,7 +1354,10 @@ class DeleteEvaluationJobRequest(proto.Message):
             "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListEvaluationJobsRequest(proto.Message):
@@ -1115,17 +1390,29 @@ class ListEvaluationJobsRequest(proto.Message):
             the first page if this is empty.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListEvaluationJobsResponse(proto.Message):
     r"""Results for listing evaluation jobs.
 
     Attributes:
-        evaluation_jobs (Sequence[google.cloud.datalabeling_v1beta1.types.EvaluationJob]):
+        evaluation_jobs (MutableSequence[google.cloud.datalabeling_v1beta1.types.EvaluationJob]):
             The list of evaluation jobs to return.
         next_page_token (str):
             A token to retrieve next page of results.
@@ -1135,10 +1422,17 @@ class ListEvaluationJobsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    evaluation_jobs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gcd_evaluation_job.EvaluationJob,
+    evaluation_jobs: MutableSequence[
+        gcd_evaluation_job.EvaluationJob
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_evaluation_job.EvaluationJob,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
