@@ -13,15 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
-from google.cloud.datalabeling_v1beta1.types import annotation
-from google.cloud.datalabeling_v1beta1.types import data_payloads
 from google.cloud.datalabeling_v1beta1.types import (
     human_annotation_config as gcd_human_annotation_config,
 )
-from google.protobuf import timestamp_pb2  # type: ignore
-
+from google.cloud.datalabeling_v1beta1.types import annotation, data_payloads
 
 __protobuf__ = proto.module(
     package="google.cloud.datalabeling.v1beta1",
@@ -72,12 +72,12 @@ class Dataset(proto.Message):
             can be up to 10000 characters long.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. Time the dataset is created.
-        input_configs (Sequence[google.cloud.datalabeling_v1beta1.types.InputConfig]):
+        input_configs (MutableSequence[google.cloud.datalabeling_v1beta1.types.InputConfig]):
             Output only. This is populated with the
             original input configs where ImportData is
             called. It is available only after the clients
             import data to this dataset.
-        blocking_resources (Sequence[str]):
+        blocking_resources (MutableSequence[str]):
             Output only. The names of any related
             resources that are blocking changes to the
             dataset.
@@ -86,13 +86,36 @@ class Dataset(proto.Message):
             dataset.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    description = proto.Field(proto.STRING, number=3,)
-    create_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    input_configs = proto.RepeatedField(proto.MESSAGE, number=5, message="InputConfig",)
-    blocking_resources = proto.RepeatedField(proto.STRING, number=6,)
-    data_item_count = proto.Field(proto.INT64, number=7,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    description: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    input_configs: MutableSequence["InputConfig"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message="InputConfig",
+    )
+    blocking_resources: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
+    data_item_count: int = proto.Field(
+        proto.INT64,
+        number=7,
+    )
 
 
 class InputConfig(proto.Message):
@@ -137,19 +160,38 @@ class InputConfig(proto.Message):
             for a model version that performs classification.
     """
 
-    text_metadata = proto.Field(
-        proto.MESSAGE, number=6, oneof="data_type_metadata", message="TextMetadata",
+    text_metadata: "TextMetadata" = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        oneof="data_type_metadata",
+        message="TextMetadata",
     )
-    gcs_source = proto.Field(
-        proto.MESSAGE, number=2, oneof="source", message="GcsSource",
+    gcs_source: "GcsSource" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="source",
+        message="GcsSource",
     )
-    bigquery_source = proto.Field(
-        proto.MESSAGE, number=5, oneof="source", message="BigQuerySource",
+    bigquery_source: "BigQuerySource" = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        oneof="source",
+        message="BigQuerySource",
     )
-    data_type = proto.Field(proto.ENUM, number=1, enum="DataType",)
-    annotation_type = proto.Field(proto.ENUM, number=3, enum=annotation.AnnotationType,)
-    classification_metadata = proto.Field(
-        proto.MESSAGE, number=4, message="ClassificationMetadata",
+    data_type: "DataType" = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum="DataType",
+    )
+    annotation_type: annotation.AnnotationType = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=annotation.AnnotationType,
+    )
+    classification_metadata: "ClassificationMetadata" = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="ClassificationMetadata",
     )
 
 
@@ -163,7 +205,10 @@ class TextMetadata(proto.Message):
             Default value is en-US.
     """
 
-    language_code = proto.Field(proto.STRING, number=1,)
+    language_code: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ClassificationMetadata(proto.Message):
@@ -175,7 +220,10 @@ class ClassificationMetadata(proto.Message):
             multi-label or not.
     """
 
-    is_multi_label = proto.Field(proto.BOOL, number=1,)
+    is_multi_label: bool = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
 
 
 class GcsSource(proto.Message):
@@ -190,8 +238,14 @@ class GcsSource(proto.Message):
             "text/csv" is supported.
     """
 
-    input_uri = proto.Field(proto.STRING, number=1,)
-    mime_type = proto.Field(proto.STRING, number=2,)
+    input_uri: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    mime_type: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class BigQuerySource(proto.Message):
@@ -219,7 +273,10 @@ class BigQuerySource(proto.Message):
             more </ml-engine/docs/continuous-evaluation/create-job#table-schema>`__.
     """
 
-    input_uri = proto.Field(proto.STRING, number=1,)
+    input_uri: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class OutputConfig(proto.Message):
@@ -246,11 +303,17 @@ class OutputConfig(proto.Message):
             This field is a member of `oneof`_ ``destination``.
     """
 
-    gcs_destination = proto.Field(
-        proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
+    gcs_destination: "GcsDestination" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        oneof="destination",
+        message="GcsDestination",
     )
-    gcs_folder_destination = proto.Field(
-        proto.MESSAGE, number=2, oneof="destination", message="GcsFolderDestination",
+    gcs_folder_destination: "GcsFolderDestination" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="destination",
+        message="GcsFolderDestination",
     )
 
 
@@ -267,8 +330,14 @@ class GcsDestination(proto.Message):
             are supported.
     """
 
-    output_uri = proto.Field(proto.STRING, number=1,)
-    mime_type = proto.Field(proto.STRING, number=2,)
+    output_uri: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    mime_type: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GcsFolderDestination(proto.Message):
@@ -280,7 +349,10 @@ class GcsFolderDestination(proto.Message):
             data to.
     """
 
-    output_folder_uri = proto.Field(proto.STRING, number=1,)
+    output_folder_uri: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DataItem(proto.Message):
@@ -315,16 +387,28 @@ class DataItem(proto.Message):
             projects/{project_id}/datasets/{dataset_id}/dataItems/{data_item_id}
     """
 
-    image_payload = proto.Field(
-        proto.MESSAGE, number=2, oneof="payload", message=data_payloads.ImagePayload,
+    image_payload: data_payloads.ImagePayload = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="payload",
+        message=data_payloads.ImagePayload,
     )
-    text_payload = proto.Field(
-        proto.MESSAGE, number=3, oneof="payload", message=data_payloads.TextPayload,
+    text_payload: data_payloads.TextPayload = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        oneof="payload",
+        message=data_payloads.TextPayload,
     )
-    video_payload = proto.Field(
-        proto.MESSAGE, number=4, oneof="payload", message=data_payloads.VideoPayload,
+    video_payload: data_payloads.VideoPayload = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        oneof="payload",
+        message=data_payloads.VideoPayload,
+    )
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    name = proto.Field(proto.STRING, number=1,)
 
 
 class AnnotatedDataset(proto.Message):
@@ -366,34 +450,68 @@ class AnnotatedDataset(proto.Message):
         metadata (google.cloud.datalabeling_v1beta1.types.AnnotatedDatasetMetadata):
             Output only. Additional information about
             AnnotatedDataset.
-        blocking_resources (Sequence[str]):
+        blocking_resources (MutableSequence[str]):
             Output only. The names of any related
             resources that are blocking changes to the
             annotated dataset.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    description = proto.Field(proto.STRING, number=9,)
-    annotation_source = proto.Field(
-        proto.ENUM, number=3, enum=annotation.AnnotationSource,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    annotation_type = proto.Field(proto.ENUM, number=8, enum=annotation.AnnotationType,)
-    example_count = proto.Field(proto.INT64, number=4,)
-    completed_example_count = proto.Field(proto.INT64, number=5,)
-    label_stats = proto.Field(proto.MESSAGE, number=6, message="LabelStats",)
-    create_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    metadata = proto.Field(
-        proto.MESSAGE, number=10, message="AnnotatedDatasetMetadata",
+    display_name: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    description: str = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    annotation_source: annotation.AnnotationSource = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=annotation.AnnotationSource,
+    )
+    annotation_type: annotation.AnnotationType = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum=annotation.AnnotationType,
+    )
+    example_count: int = proto.Field(
+        proto.INT64,
+        number=4,
+    )
+    completed_example_count: int = proto.Field(
+        proto.INT64,
+        number=5,
+    )
+    label_stats: "LabelStats" = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="LabelStats",
+    )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    metadata: "AnnotatedDatasetMetadata" = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message="AnnotatedDatasetMetadata",
+    )
+    blocking_resources: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=11,
     )
-    blocking_resources = proto.RepeatedField(proto.STRING, number=11,)
 
 
 class LabelStats(proto.Message):
     r"""Statistics about annotation specs.
 
     Attributes:
-        example_count (Sequence[google.cloud.datalabeling_v1beta1.types.LabelStats.ExampleCountEntry]):
+        example_count (MutableMapping[str, int]):
             Map of each annotation spec's example count.
             Key is the annotation spec name and value is the
             number of examples for that annotation spec. If
@@ -403,7 +521,11 @@ class LabelStats(proto.Message):
             annotations.
     """
 
-    example_count = proto.MapField(proto.STRING, proto.INT64, number=1,)
+    example_count: MutableMapping[str, int] = proto.MapField(
+        proto.STRING,
+        proto.INT64,
+        number=1,
+    )
 
 
 class AnnotatedDatasetMetadata(proto.Message):
@@ -466,70 +588,78 @@ class AnnotatedDatasetMetadata(proto.Message):
             AnnotatedDataset.
     """
 
-    image_classification_config = proto.Field(
+    image_classification_config: gcd_human_annotation_config.ImageClassificationConfig = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="annotation_request_config",
         message=gcd_human_annotation_config.ImageClassificationConfig,
     )
-    bounding_poly_config = proto.Field(
+    bounding_poly_config: gcd_human_annotation_config.BoundingPolyConfig = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="annotation_request_config",
         message=gcd_human_annotation_config.BoundingPolyConfig,
     )
-    polyline_config = proto.Field(
+    polyline_config: gcd_human_annotation_config.PolylineConfig = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="annotation_request_config",
         message=gcd_human_annotation_config.PolylineConfig,
     )
-    segmentation_config = proto.Field(
+    segmentation_config: gcd_human_annotation_config.SegmentationConfig = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="annotation_request_config",
         message=gcd_human_annotation_config.SegmentationConfig,
     )
-    video_classification_config = proto.Field(
+    video_classification_config: gcd_human_annotation_config.VideoClassificationConfig = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="annotation_request_config",
         message=gcd_human_annotation_config.VideoClassificationConfig,
     )
-    object_detection_config = proto.Field(
-        proto.MESSAGE,
-        number=7,
-        oneof="annotation_request_config",
-        message=gcd_human_annotation_config.ObjectDetectionConfig,
+    object_detection_config: gcd_human_annotation_config.ObjectDetectionConfig = (
+        proto.Field(
+            proto.MESSAGE,
+            number=7,
+            oneof="annotation_request_config",
+            message=gcd_human_annotation_config.ObjectDetectionConfig,
+        )
     )
-    object_tracking_config = proto.Field(
-        proto.MESSAGE,
-        number=8,
-        oneof="annotation_request_config",
-        message=gcd_human_annotation_config.ObjectTrackingConfig,
+    object_tracking_config: gcd_human_annotation_config.ObjectTrackingConfig = (
+        proto.Field(
+            proto.MESSAGE,
+            number=8,
+            oneof="annotation_request_config",
+            message=gcd_human_annotation_config.ObjectTrackingConfig,
+        )
     )
-    event_config = proto.Field(
+    event_config: gcd_human_annotation_config.EventConfig = proto.Field(
         proto.MESSAGE,
         number=9,
         oneof="annotation_request_config",
         message=gcd_human_annotation_config.EventConfig,
     )
-    text_classification_config = proto.Field(
-        proto.MESSAGE,
-        number=10,
-        oneof="annotation_request_config",
-        message=gcd_human_annotation_config.TextClassificationConfig,
+    text_classification_config: gcd_human_annotation_config.TextClassificationConfig = (
+        proto.Field(
+            proto.MESSAGE,
+            number=10,
+            oneof="annotation_request_config",
+            message=gcd_human_annotation_config.TextClassificationConfig,
+        )
     )
-    text_entity_extraction_config = proto.Field(
+    text_entity_extraction_config: gcd_human_annotation_config.TextEntityExtractionConfig = proto.Field(
         proto.MESSAGE,
         number=11,
         oneof="annotation_request_config",
         message=gcd_human_annotation_config.TextEntityExtractionConfig,
     )
-    human_annotation_config = proto.Field(
-        proto.MESSAGE,
-        number=1,
-        message=gcd_human_annotation_config.HumanAnnotationConfig,
+    human_annotation_config: gcd_human_annotation_config.HumanAnnotationConfig = (
+        proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message=gcd_human_annotation_config.HumanAnnotationConfig,
+        )
     )
 
 
@@ -564,24 +694,38 @@ class Example(proto.Message):
             Output only. Name of the example, in format of:
             projects/{project_id}/datasets/{dataset_id}/annotatedDatasets/
             {annotated_dataset_id}/examples/{example_id}
-        annotations (Sequence[google.cloud.datalabeling_v1beta1.types.Annotation]):
+        annotations (MutableSequence[google.cloud.datalabeling_v1beta1.types.Annotation]):
             Output only. Annotations for the piece of
             data in Example. One piece of data can have
             multiple annotations.
     """
 
-    image_payload = proto.Field(
-        proto.MESSAGE, number=2, oneof="payload", message=data_payloads.ImagePayload,
+    image_payload: data_payloads.ImagePayload = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="payload",
+        message=data_payloads.ImagePayload,
     )
-    text_payload = proto.Field(
-        proto.MESSAGE, number=6, oneof="payload", message=data_payloads.TextPayload,
+    text_payload: data_payloads.TextPayload = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        oneof="payload",
+        message=data_payloads.TextPayload,
     )
-    video_payload = proto.Field(
-        proto.MESSAGE, number=7, oneof="payload", message=data_payloads.VideoPayload,
+    video_payload: data_payloads.VideoPayload = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        oneof="payload",
+        message=data_payloads.VideoPayload,
     )
-    name = proto.Field(proto.STRING, number=1,)
-    annotations = proto.RepeatedField(
-        proto.MESSAGE, number=5, message=annotation.Annotation,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    annotations: MutableSequence[annotation.Annotation] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=annotation.Annotation,
     )
 
 
